@@ -8,6 +8,8 @@ from Products.Archetypes.public import DisplayList
 ## 
 ## After changing this file you need to restart plone !
 
+theYears = range(1995,2016)
+
 theDonors = (
 'US AID',
 'ECHO',
@@ -64,6 +66,10 @@ ACTED_SECTORS = DisplayList()
 for sector in theSectors:
    ACTED_SECTORS.add(sector,sector)
 
+ACTED_YEARS = DisplayList()
+for year in theYears:
+   ACTED_YEARS.add(year,year)
+
 
 PROJECTNAME = 'acted.projects'
 ADD_PERMISSIONS = {
