@@ -20,6 +20,7 @@ from Products.Archetypes.public import FloatField, DecimalWidget
 from acted.projects.config import ACTED_COUNTRIES
 from acted.projects.config import ACTED_SECTORS
 from acted.projects.config import ACTED_DONORS
+from acted.projects.config import ACTED_YEARS
 
 
 
@@ -91,16 +92,18 @@ ACTEDProjectSchema = schemata.ATContentTypeSchema.copy() + atapi.Schema((
         label=_(u'Year of Contract Signature'),
         format='select'
       ),
-      vocabulary=['2000','2001','2002'],
+#      vocabulary=['2000','2001','2002','2003','2004','2004','2005','2006','2007','2008','2009','2010',],
+      vocabulary=ACTED_YEARS,
       enforceVocabulary=True,
       required=True,
       searchable=False
     ),
 
-    atapi.FloatField(
+    atapi.StringField(
         name='projectBudget',
-        widget=DecimalWidget(
-            label=_(u'Budget (Euros)'),
+        widget=atapi.StringWidget(
+            label=_(u'Budget'),
+            size=20
       ),
       required=False,
       searchable=False
